const lightCodeTheme = require("prism-react-renderer/themes/github");
const darkCodeTheme = require("prism-react-renderer/themes/dracula");

/** @type {import('@docusaurus/types').DocusaurusConfig} */
module.exports = {
  title: "Simplifiez-vous le code",
  tagline: "",
  url: process.env.DOCUSAURUS_URL || "https://froggit.fr",
  baseUrl: process.env.DOCUSAURUS_BASEURL || "/",
  onBrokenLinks: "throw",
  onBrokenMarkdownLinks: "warn",
  favicon: "img/favicon/favicon.ico",
  organizationName: "froggit/www", // Usually your GitHub org/user name.
  projectName: "froggit.fr", // Usually your repo name.
  themeConfig: {
    navbar: {
      title: "",
      logo: {
        alt: "Froggit Logo",
        src: "img/theme/logo_typo_froggit.png",
      },
      items: [      
        {label: "Fonctionnalités", position: "left", to: "/#features", exact: true},
        {label: "FAQ", position: "left", to: "/faq"},
        {label: "Tarifs", position: "left", to: "/tarifs"},
        {label: "Doc", position: "left", type: "doc", docId: "intro", },
        {label: "🎁 Antisèche et Communauté git", position: "left", to: "/communaute"},
        {
          label: "👤 Connexion",
          position: "right",
          href: "https://lab.frogg.it/users/sign_in",
        },
        {label: "S'enregistrer", position: "right", to: "/tarifs"},
        {
          type: "dropdown",
          label: "Les services",
          position: "right",
          items: [
            {
              label: "Le Lab 🧪",
              href: "https://lab.frogg.it/",
            },
            {
              label: "Le Chat 💬",
              href: "https://chat.froggit.fr/",
            },
            {
              label: "Status ✔",
              href: "https://status.froggit.fr/",
            },
          ],
        },
      ],
    },
    footer: {
      style: "dark",
      links: [
        {
          title: "Pourquoi Froggit ?",
          items: [
            {
              label: "🔐 Ton code source est-il en sécurité?",
              href: "https://lydra.fr/es-2-ton-code-source-est-il-vraiment-en-securite/",
            },
            {
              label: "La souveraineté numérique",
              href: "https://lydra.fr/category/souverainete-numerique/",
            },
            {
              label: "git kesako ?",
              href: "https://github.com/git-guides/",
            },
          ],
        },
        {
          title: "Support",
          items: [
            {
              label: "Contact",
              to: "/contacts",
            },
            {
              label: "✔️ Status",
              href: "https://status.froggit.fr",
            },
          ],
        },     
        {
          title: "Société",
          items: [
            {
              label: "À propos",
              href: "https://lydra.fr",
            },
            {
              label: "Équipe",
              href: "https://lydra.fr/#team",
            },
            {
              label: "Sous-traitants",
              to: "/sous-traitants",
            },
            {
              label: "Mentions légales",
              to: "/mentions_legales",
            },
            {
              label: "📜 CGV",
              to: "/CGV",
            },
            {
              label: "📃 CGU",
              to: "/CGU",
            },
            {
              label: "Politique de confidentialité",
              to: "/confidentialite",
            },
          ],
        },
      ],
      // eslint-disable-next-line quotes
      copyright: `Lydra © ${new Date().getFullYear()}` +"<br/>"+ `Froggit est fièrement fabriqué avec ❤️ par <a href="http://lydra.fr/">Lydra</a> avec des Logiciels Libres et hébergé en 🇫🇷 chez <a href="https://www.scaleway.fr/">Scaleway</a>` +"<br/>"+ `Construit avec <a href="https://docusaurus.io/fr">Docusaurus</a>`,
    },
    prism: {
      theme: lightCodeTheme,
      darkTheme: darkCodeTheme,
    },
  },
  presets: [
    [
      "@docusaurus/preset-classic",
      {
        docs: {
          sidebarPath: require.resolve("./sidebars.js"),
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master",
        },
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master/blog/",
        },
        theme: {
          customCss: require.resolve("./src/css/custom.css"),
        },
      },
    ],
  ],
  plugins: [
    [
      // https://github.com/gabrielcsapo/docusaurus-plugin-matomo#usage
      require.resolve("@gabrielcsapo/docusaurus-plugin-matomo"),
      {
        siteId: "5",
        matomoUrl: "https://stats.esprit-libre-conseil.com",
        siteUrl: process.env.DOCUSAURUS_URL || "https://froggit.fr",
        matomoPhpScript: "m.php",
        matomoJsScript: "m.js",
        enableJSErrorTracking: true,
      },
    ],
  ],
};
